@@ -3,7 +3,7 @@ import time, pdb
 from subprocess import call
 
 seconds_listen_channel = 5*60 # seconds
-my_username = u"fenton"
+my_username = "fenton"
 debug = True
 monitored_channels = {} # "channel_name": time_i_last_chatted
 
@@ -15,22 +15,22 @@ def generate_actions_from_irc_message(args,printer):
     # notification if the message is on a channel I'm monitoring, or play a
     # sound if a message is directly to me.
     global monitored_channels
-    from_who = args[u"from_who"]
-    channel = args[u"channel"]
-    message = args[u"message"]
-    to_me = args[u"to_me"]
+    from_who = args["from_who"]
+    channel = args["channel"]
+    message = args["message"]
+    to_me = args["to_me"]
 
     actions_todo = []
     from_me = i_wrote_message(from_who)
 
     if to_me:
         alert_title, alrt_msg = construct_alert(from_who, channel, message)
-        actions_todo.append({u"action": display_alert, 
-                             u"arguments": {u"alert_title": alert_title, 
-                                           u"alert_message": alrt_msg,
-                                           u"urgency": u"high"}} )
-        actions_todo.append({u"action": play_sound,
-                             u"arguments": {u"sound_file": u"irc-message"}})
+        actions_todo.append({"action": display_alert, 
+                             "arguments": {"alert_title": alert_title, 
+                                           "alert_message": alrt_msg,
+                                           "urgency": "high"}} )
+        actions_todo.append({"action": play_sound,
+                             "arguments": {"sound_file": "irc-message"}})
 
     remove_expired_channels(monitored_channels)
 
@@ -49,10 +49,10 @@ def generate_actions_from_irc_message(args,printer):
     if not to_me and not from_me and monitoring_channel:
         elapsed_time = get_elapsed_time_on_channel(channel, monitored_channels)
         alert_title, alrt_msg = construct_alert(from_who, channel, message, elapsed_time)
-        actions_todo.append({u"action": display_alert,
-                             u"arguments": {u"alert_title": alert_title, 
-                                           u"alert_message": alrt_msg,
-                                           u"urgency": u"low"}} )
+        actions_todo.append({"action": display_alert,
+                             "arguments": {"alert_title": alert_title, 
+                                           "alert_message": alrt_msg,
+                                           "urgency": "low"}} )
         if debug:
             printer("Monitoring Channel Msg" + channel, "channels: " + str(monitored_channels))
                     
@@ -63,8 +63,8 @@ def generate_actions_from_irc_message(args,printer):
 # hash/dict as an argument, this contains the actual arguments.
 def perform_actions(action_list, printer):
     for action in action_list:
-        function = action[u"action"]
-        arguments = action[u"arguments"]
+        function = action["action"]
+        arguments = action["arguments"]
         function(arguments, printer)
 
 #######################
@@ -171,22 +171,19 @@ def i_wrote_message(who):
 
 def construct_notification_command( title, body, urgency ):
     # notify-send -h string:bgcolor:#ff0000 -h string:fgcolor:#ff444 'Hello world!' 'This is an example notification.' --icon=dialog-information
-    cmd = [u"notify-send"]
-    if urgency == u"high":
-        cmd += [u"-h",u"string:bgcolor:#ff0000",u"-h",u"string:fgcolor:#ffffff"]
-    if urgency == u"low":
-        cmd += [u"-h",u"string:bgcolor:#000000",u"-h",u"string:fgcolor:#888888"]
+    cmd = ["notify-send"]
+    if urgency == "high":
+        cmd += ["-h","string:bgcolor:#ff0000","-h","string:fgcolor:#ffffff"]
+    if urgency == "low":
+        cmd += ["-h","string:bgcolor:#000000","-h","string:fgcolor:#888888"]
     cmd += [title,body]
     return cmd
 
 def init(args): # in_my_username, in_seconds_listen_channel):
     global my_username
     global seconds_listen_channel
-    my_username = args[u"username"]
-    seconds_listen_channel = args[u"monitor_time"]
-
-# Notify.init (u"Notify Init")
-
+    my_username = args["username"]
+    seconds_listen_channel = args["monitor_time"]
 
 def display_actions(actions):
     print( "RESPONSE:" )
